const mongoose = require('mongoose');
const express = require('express')
const jimp = require('jimp')
const bp = require('body-parser')
const fs = require('fs')
const app = express()
const port = 80

// DB stuff
const db  = mongoose.connection;
const mongoDBURL = 'mongodb://127.0.0.1/memes';
mongoose.connect(mongoDBURL, { useNewUrlParser: true });
db.on('error', () => { 
  console.log('MongoDB connection error:') 
});

var MemeSchema = new mongoose.Schema({
  fileName: String,
  text: String
});    
var Meme = mongoose.model('Meme', MemeSchema );
       

app.use(express.static('public_html'))
app.use(bp.json());

app.post('/creatememe', function (req, res) {
  var template = req.body.template;
  var topText = req.body.top;
  var bottomText = req.body.bottom;
  var inputFileName = './images/' + template + '.png'
  var imgFile = Math.floor(Math.random() * 10000) + '.png';
  var outputFileName = './public_html/' + imgFile;

 // update to use promises

  let image = undefined;

  jimp.read(inputFileName).then((img) => {
      image = img;
      return jimp.loadFont(jimp.FONT_SANS_32_WHITE);
  }).then((font) => {
      image.print(font, 10, 10, topText);
      image.print(font, 10, 350, bottomText);
      return image.write(outputFileName);
  }).then((image) => {
      let newMeme = new Meme({ fileName: imgFile, text: topText + ' ' + bottomText });
      return newMeme.save();
  }).then((result) => { 
      let r = { name: "/" + imgFile };
      res.json(r);
  }).catch((err) => { 
      console.log(err);
      res.json({"error": "yikes"});
  });

});

app.get('/memes/search/:term', function (req, res) {
  console.log('I got here!');
  let p = Meme.find({ text : { $regex : req.params.term } }).exec();
  p.then((documents) => {
    res.json(documents);
  });
});

app.get('/memes/get', function (req, res) {
  let p = Meme.find({}).exec();
  p.then((documents) => {
    res.json(documents);
  });
});

app.listen(port, () => 
  console.log(`App listening at http://localhost:${port}`));
